@@ -34,59 +34,60 @@ class Console::CommandDispatcher::Core
   end
 
   @@irb_opts = Rex::Parser::Arguments.new(
-    "-h" => [ false, "Help banner."                  ],
-    "-e" => [ true,  "Expression to evaluate."       ])
+    '-h' => [false, 'Help banner.'],
+    '-e' => [true,  'Expression to evaluate.'])
 
   @@load_opts = Rex::Parser::Arguments.new(
-    "-l" => [ false, "List all available extensions" ],
-    "-h" => [ false, "Help menu."                    ])
+    '-l' => [false, 'List all available extensions'],
+    '-h' => [false, 'Help menu.'])
 
   #
   # List of supported commands.
   #
   def commands
     c = {
-      "?"          => "Help menu",
-      "background" => "Backgrounds the current session",
-      "close"      => "Closes a channel",
-      "channel"    => "Displays information or control active channels",
-      "exit"       => "Terminate the meterpreter session",
-      "help"       => "Help menu",
-      "irb"        => "Drop into irb scripting mode",
-      "use"        => "Deprecated alias for 'load'",
-      "load"       => "Load one or more meterpreter extensions",
-      "machine_id" => "Get the MSF ID of the machine attached to the session",
-      "quit"       => "Terminate the meterpreter session",
-      "resource"   => "Run the commands stored in a file",
-      "uuid"       => "Get the UUID for the current session",
-      "read"       => "Reads data from a channel",
-      "run"        => "Executes a meterpreter script or Post module",
-      "bgrun"      => "Executes a meterpreter script as a background thread",
-      "bgkill"     => "Kills a background meterpreter script",
-      "get_timeouts" => "Get the current session timeout values",
-      "set_timeouts" => "Set the current session timeout values",
-      "sess"       => "Quickly switch to another session",
-      "bglist"     => "Lists running background scripts",
-      "write"      => "Writes data to a channel",
-      "enable_unicode_encoding"  => "Enables encoding of unicode strings",
-      "disable_unicode_encoding" => "Disables encoding of unicode strings"
+      '?'            => 'Help menu',
+      'background'   => 'Backgrounds the current session',
+      'close'        => 'Closes a channel',
+      'channel'      => 'Displays information or control active channels',
+      'exit'         => 'Terminate the meterpreter session',
+      'help'         => 'Help menu',
+      'irb'          => 'Drop into irb scripting mode',
+      'use'          => 'Deprecated alias for "load"',
+      'load'         => 'Load one or more meterpreter extensions',
+      'machine_id'   => 'Get the MSF ID of the machine attached to the session',
+      'guid'         => 'Get the session GUID',
+      'quit'         => 'Terminate the meterpreter session',
+      'resource'     => 'Run the commands stored in a file',
+      'uuid'         => 'Get the UUID for the current session',
+      'read'         => 'Reads data from a channel',
+      'run'          => 'Executes a meterpreter script or Post module',
+      'bgrun'        => 'Executes a meterpreter script as a background thread',
+      'bgkill'       => 'Kills a background meterpreter script',
+      'get_timeouts' => 'Get the current session timeout values',
+      'set_timeouts' => 'Set the current session timeout values',
+      'sessions'     => 'Quickly switch to another session',
+      'bglist'       => 'Lists running background scripts',
+      'write'        => 'Writes data to a channel',
+      'enable_unicode_encoding'  => 'Enables encoding of unicode strings',
+      'disable_unicode_encoding' => 'Disables encoding of unicode strings'
     }
 
     if client.passive_service
-      c["detach"] = "Detach the meterpreter session (for http/https)"
+      c['detach'] = 'Detach the meterpreter session (for http/https)'
     end
 
     # Currently we have some windows-specific core commands`
     if client.platform == 'windows'
       # only support the SSL switching for HTTPS
       if client.passive_service && client.sock.type? == 'tcp-ssl'
-        c["ssl_verify"] = "Modify the SSL certificate verification setting"
+        c['ssl_verify'] = 'Modify the SSL certificate verification setting'
       end
     end
 
     if client.platform == 'windows' || client.platform == 'linux'
       # Migration only supported on windows and linux
-      c["migrate"] = "Migrate the server to another process"
+      c['migrate'] = 'Migrate the server to another process'
     end
 
     # TODO: This code currently checks both platform and architecture for the python
@@ -95,17 +96,17 @@ class Console::CommandDispatcher::Core
     # the platform update feature we can remove some of these conditions
     if client.platform == 'windows' || client.platform == 'linux' ||
         client.platform == 'python' || client.platform == 'java' ||
-        client.arch == ARCH_PYTHON || (client.arch == ARCH_JAVA && client.platform != 'android')
+        client.arch == ARCH_PYTHON || client.platform == 'android'
       # Yet to implement transport hopping for other meterpreters.
-      c["transport"] = "Change the current transport mechanism"
+      c['transport'] = 'Change the current transport mechanism'
 
       # sleep functionality relies on the transport features, so only
       # wire that in with the transport stuff.
-      c["sleep"] = "Force Meterpreter to go quiet, then re-establish session."
+      c['sleep'] = 'Force Meterpreter to go quiet, then re-establish session.'
     end
 
     if msf_loaded?
-      c["info"] = "Displays information about a Post module"
+      c['info'] = 'Displays information about a Post module'
     end
 
     c
@@ -115,20 +116,20 @@ class Console::CommandDispatcher::Core
   # Core baby.
   #
   def name
-    "Core"
+    'Core'
   end
 
-  def cmd_sess_help
-    print_line('Usage: sess <session id>')
+  def cmd_sessions_help
+    print_line('Usage: sessions <id>')
     print_line
     print_line('Interact with a different session Id.')
     print_line('This works the same as calling this from the MSF shell: sessions -i <session id>')
     print_line
   end
 
-  def cmd_sess(*args)
+  def cmd_sessions(*args)
     if args.length == 0 || args[0].to_i == 0
-      cmd_sess_help
+      cmd_sessions_help
     elsif args[0].to_s == client.name.to_s
       print_status("Session #{client.name} is already interactive.")
     else
@@ -141,14 +142,14 @@ class Console::CommandDispatcher::Core
   end
 
   def cmd_background_help
-    print_line "Usage: background"
+    print_line('Usage: background')
     print_line
-    print_line "Stop interacting with this session and return to the parent prompt"
+    print_line('Stop interacting with this session and return to the parent prompt')
     print_line
   end
 
   def cmd_background
-    print_status "Backgrounding session #{client.name}..."
+    print_status("Backgrounding session #{client.name}...")
     client.interacting = false
   end
 
@@ -156,26 +157,26 @@ class Console::CommandDispatcher::Core
   # Displays information about active channels
   #
   @@channel_opts = Rex::Parser::Arguments.new(
-    "-c" => [ true,  "Close the given channel." ],
-    "-k" => [ true,  "Close the given channel." ],
-    "-i" => [ true,  "Interact with the given channel." ],
-    "-l" => [ false, "List active channels." ],
-    "-r" => [ true,  "Read from the given channel." ],
-    "-w" => [ true,  "Write to the given channel." ],
-    "-h" => [ false, "Help menu." ])
+    '-c' => [ true,  'Close the given channel.' ],
+    '-k' => [ true,  'Close the given channel.' ],
+    '-i' => [ true,  'Interact with the given channel.' ],
+    '-l' => [ false, 'List active channels.' ],
+    '-r' => [ true,  'Read from the given channel.' ],
+    '-w' => [ true,  'Write to the given channel.' ],
+    '-h' => [ false, 'Help menu.' ])
 
   def cmd_channel_help
-    print_line "Usage: channel [options]"
+    print_line('Usage: channel [options]')
     print_line
-    print_line "Displays information about active channels."
-    print_line @@channel_opts.usage
+    print_line('Displays information about active channels.')
+    print_line(@@channel_opts.usage)
   end
 
   #
   # Performs operations on the supplied channel.
   #
   def cmd_channel(*args)
-    if args.empty? or args.include?("-h") or args.include?("--help")
+    if args.empty? || args.include?('-h')
       cmd_channel_help
       return
     end
@@ -186,24 +187,25 @@ class Console::CommandDispatcher::Core
     # Parse options
     @@channel_opts.parse(args) { |opt, idx, val|
       case opt
-      when "-l"
+      when '-l'
         mode = :list
-      when "-c", "-k"
+      when '-c', '-k'
         mode = :close
         chan = val
-      when "-i"
+      when '-i'
         mode = :interact
         chan = val
-      when "-r"
+      when '-r'
         mode = :read
         chan = val
-      when "-w"
+      when '-w'
         mode = :write
         chan = val
       end
+
       if @@channel_opts.arg_required?(opt)
         unless chan
-          print_error("Channel ID required")
+          print_error('Channel ID required')
           return
         end
       end
@@ -213,12 +215,7 @@ class Console::CommandDispatcher::Core
     when :list
       tbl = Rex::Text::Table.new(
         'Indent'  => 4,
-        'Columns' =>
-          [
-            'Id',
-            'Class',
-            'Type'
-          ])
+        'Columns' => ['Id', 'Class', 'Type'])
       items = 0
 
       client.channels.each_pair { |cid, channel|
@@ -227,7 +224,7 @@ class Console::CommandDispatcher::Core
       }
 
       if (items == 0)
-        print_line("No active channels.")
+        print_line('No active channels.')
       else
         print("\n" + tbl.to_s + "\n")
       end
@@ -251,7 +248,7 @@ class Console::CommandDispatcher::Core
       @@channel_opts.fmt.keys
     when 2
       case words[1]
-      when "-k", "-c", "-i", "-r", "-w"
+      when '-k', '-c', '-i', '-r', '-w'
         tab_complete_channels
       else
         []
@@ -262,9 +259,9 @@ class Console::CommandDispatcher::Core
   end
 
   def cmd_close_help
-    print_line "Usage: close <channel_id>"
+    print_line('Usage: close <channel_id>')
     print_line
-    print_line "Closes the supplied channel."
+    print_line('Closes the supplied channel.')
     print_line
   end
 
@@ -272,22 +269,22 @@ class Console::CommandDispatcher::Core
   # Closes a supplied channel.
   #
   def cmd_close(*args)
-    if (args.length == 0)
+    if args.length == 0
       cmd_close_help
       return true
     end
 
-    cid     = args[0].to_i
+    cid = args[0].to_i
     channel = client.find_channel(cid)
 
-    if (!channel)
-      print_error("Invalid channel identifier specified.")
+    unless channel
+      print_error('Invalid channel identifier specified.')
       return true
-    else
-      channel._close # Issue #410
-
-      print_status("Closed channel #{cid}.")
     end
+
+    channel._close # Issue #410
+
+    print_status("Closed channel #{cid}.")
   end
 
   def cmd_close_tabs(str, words)
@@ -300,7 +297,7 @@ class Console::CommandDispatcher::Core
   # Terminates the meterpreter session.
   #
   def cmd_exit(*args)
-    print_status("Shutting down Meterpreter...")
+    print_status('Shutting down Meterpreter...')
     client.core.shutdown rescue nil
     client.shutdown_passive_dispatcher
     shell.stop
@@ -309,13 +306,13 @@ class Console::CommandDispatcher::Core
   alias cmd_quit cmd_exit
 
   def cmd_detach_help
-    print_line "Detach from the victim. Only possible for non-stream sessions (http/https)"
+    print_line('Detach from the victim. Only possible for non-stream sessions (http/https)')
     print_line
-    print_line "The victim will continue to attempt to call back to the handler until it"
-    print_line "successfully connects (which may happen immediately if you have a handler"
-    print_line "running in the background), or reaches its expiration."
+    print_line('The victim will continue to attempt to call back to the handler until it')
+    print_line('successfully connects (which may happen immediately if you have a handler')
+    print_line('running in the background), or reaches its expiration.')
     print_line
-    print_line "This session may #{client.passive_service ? "" : "NOT"} be detached."
+    print_line("This session may #{client.passive_service ? "" : "NOT"} be detached.")
     print_line
   end
 
@@ -328,9 +325,9 @@ class Console::CommandDispatcher::Core
   end
 
   def cmd_interact_help
-    print_line "Usage: interact <channel_id>"
+    print_line('Usage: interact <channel_id>')
     print_line
-    print_line "Interacts with the supplied channel."
+    print_line('Interacts with the supplied channel.')
     print_line
   end
 
@@ -338,29 +335,29 @@ class Console::CommandDispatcher::Core
   # Interacts with a channel.
   #
   def cmd_interact(*args)
-    if (args.length == 0)
+    if args.length == 0
       cmd_info_help
       return true
     end
 
-    cid     = args[0].to_i
+    cid = args[0].to_i
     channel = client.find_channel(cid)
 
-    if (channel)
+    if channel
       print_line("Interacting with channel #{cid}...\n")
 
       shell.interact_with_channel(channel)
     else
-      print_error("Invalid channel identifier specified.")
+      print_error('Invalid channel identifier specified.')
     end
   end
 
   alias cmd_interact_tabs cmd_close_tabs
 
   def cmd_irb_help
-    print_line "Usage: irb"
+    print_line('Usage: irb')
     print_line
-    print_line "Execute commands in a Ruby environment"
+    print_line('Execute commands in a Ruby environment')
     print @@irb_opts.usage
   end
 
@@ -384,8 +381,9 @@ class Console::CommandDispatcher::Core
     framework = client.framework
 
     if expressions.empty?
-      print_status("Starting IRB shell")
-      print_status("The 'client' variable holds the meterpreter client\n")
+      print_status('Starting IRB shell')
+      print_status('The "client" variable holds the meterpreter client')
+      print_line
 
       Rex::Ui::Text::IrbShell.new(binding).run
     else
@@ -394,11 +392,11 @@ class Console::CommandDispatcher::Core
   end
 
   @@set_timeouts_opts = Rex::Parser::Arguments.new(
-    '-c' => [ true,  'Comms timeout (seconds)' ],
-    '-x' => [ true,  'Expiration timout (seconds)' ],
-    '-t' => [ true,  'Retry total time (seconds)' ],
-    '-w' => [ true,  'Retry wait time (seconds)' ],
-    '-h' => [ false, 'Help menu' ])
+    '-c' => [true, 'Comms timeout (seconds)'],
+    '-x' => [true, 'Expiration timout (seconds)'],
+    '-t' => [true, 'Retry total time (seconds)'],
+    '-w' => [true, 'Retry wait time (seconds)'],
+    '-h' => [false, 'Help menu'])
 
   def cmd_set_timeouts_help
     print_line('Usage: set_timeouts [options]')
@@ -409,7 +407,7 @@ class Console::CommandDispatcher::Core
   end
 
   def cmd_set_timeouts(*args)
-    if ( args.length == 0 or args.include?("-h") )
+    if args.length == 0 || args.include?('-h')
       cmd_set_timeouts_help
       return
     end
@@ -430,7 +428,7 @@ class Console::CommandDispatcher::Core
     end
 
     if opts.keys.length == 0
-      print_error("No options set")
+      print_error('No options set')
     else
       timeouts = client.core.set_transport_timeouts(opts)
       print_timeouts(timeouts)
@@ -467,6 +465,15 @@ class Console::CommandDispatcher::Core
     print_good("Machine ID: #{client.machine_id}")
   end
 
+  #
+  # Get the session GUID
+  #
+  def cmd_guid(*args)
+    parts = client.session_guid.unpack('H*')[0]
+    guid = [parts[0, 8], parts[8, 4], parts[12, 4], parts[16, 4], parts[20, 12]].join('-')
+    print_good("Session GUID: #{guid}")
+  end
+
   #
   # Get the machine ID of the target (should always be up to date locally)
   #
@@ -534,7 +541,7 @@ class Console::CommandDispatcher::Core
       if hash
         print_good("SSL verification is enabled. SHA1 Hash: #{hash.unpack("H*")[0]}")
       else
-        print_good("SSL verification is disabled.")
+        print_good('SSL verification is disabled.')
       end
 
     elsif enable
@@ -542,14 +549,14 @@ class Console::CommandDispatcher::Core
       if hash
         print_good("SSL verification has been enabled. SHA1 Hash: #{hash.unpack("H*")[0]}")
       else
-        print_error("Failed to enable SSL verification")
+        print_error('Failed to enable SSL verification')
       end
 
     else
       if client.core.disable_ssl_hash_verify
         print_good('SSL verification has been disabled')
       else
-        print_error("Failed to disable SSL verification")
+        print_error('Failed to disable SSL verification')
       end
     end
 
@@ -598,25 +605,24 @@ class Console::CommandDispatcher::Core
   # Arguments for transport switching
   #
   @@transport_opts = Rex::Parser::Arguments.new(
-    '-t'  => [ true,  "Transport type: #{Rex::Post::Meterpreter::ClientCore::VALID_TRANSPORTS.keys.join(', ')}" ],
-    '-l'  => [ true,  'LHOST parameter (for reverse transports)' ],
-    '-p'  => [ true,  'LPORT parameter' ],
-    '-i'  => [ true,  'Specify transport by index (currently supported: remove)' ],
-    '-u'  => [ true,  'Custom URI for HTTP/S transports (used when removing transports)' ],
-    '-lu' => [ true,  'Local URI for HTTP/S transports (used when adding/changing transports with a custom LURI)' ],
-    '-ua' => [ true,  'User agent for HTTP/S transports (optional)' ],
-    '-ph' => [ true,  'Proxy host for HTTP/S transports (optional)' ],
-    '-pp' => [ true,  'Proxy port for HTTP/S transports (optional)' ],
-    '-pu' => [ true,  'Proxy username for HTTP/S transports (optional)' ],
-    '-ps' => [ true,  'Proxy password for HTTP/S transports (optional)' ],
-    '-pt' => [ true,  'Proxy type for HTTP/S transports (optional: http, socks; default: http)' ],
-    '-c'  => [ true,  'SSL certificate path for https transport verification (optional)' ],
-    '-to' => [ true,  'Comms timeout (seconds) (default: same as current session)' ],
-    '-ex' => [ true,  'Expiration timout (seconds) (default: same as current session)' ],
-    '-rt' => [ true,  'Retry total time (seconds) (default: same as current session)' ],
-    '-rw' => [ true,  'Retry wait time (seconds) (default: same as current session)' ],
-    '-v'  => [ false, 'Show the verbose format of the transport list' ],
-    '-h'  => [ false, 'Help menu' ])
+    '-t' => [true, "Transport type: #{Rex::Post::Meterpreter::ClientCore::VALID_TRANSPORTS.keys.join(', ')}"],
+    '-l' => [true, 'LHOST parameter (for reverse transports)'],
+    '-p' => [true, 'LPORT parameter'],
+    '-i' => [true, 'Specify transport by index (currently supported: remove)'],
+    '-u' => [true, 'Local URI for HTTP/S transports (used when adding/changing transports with a custom LURI)'],
+    '-c' => [true, 'SSL certificate path for https transport verification (optional)'],
+    '-A' => [true, 'User agent for HTTP/S transports (optional)'],
+    '-H' => [true, 'Proxy host for HTTP/S transports (optional)'],
+    '-P' => [true, 'Proxy port for HTTP/S transports (optional)'],
+    '-U' => [true, 'Proxy username for HTTP/S transports (optional)'],
+    '-N' => [true, 'Proxy password for HTTP/S transports (optional)'],
+    '-B' => [true, 'Proxy type for HTTP/S transports (optional: http, socks; default: http)'],
+    '-C' => [true, 'Comms timeout (seconds) (default: same as current session)'],
+    '-X' => [true, 'Expiration timout (seconds) (default: same as current session)'],
+    '-T' => [true, 'Retry total time (seconds) (default: same as current session)'],
+    '-W' => [true, 'Retry wait time (seconds) (default: same as current session)'],
+    '-v' => [false, 'Show the verbose format of the transport list'],
+    '-h' => [false, 'Help menu'])
 
   #
   # Display help for transport management.
@@ -656,23 +662,22 @@ class Console::CommandDispatcher::Core
     end
 
     opts = {
-      :uuid          => client.payload_uuid,
-      :transport     => nil,
-      :lhost         => nil,
-      :lport         => nil,
-      :uri           => nil,
-      :ua            => nil,
-      :proxy_host    => nil,
-      :proxy_port    => nil,
-      :proxy_type    => nil,
-      :proxy_user    => nil,
-      :proxy_pass    => nil,
-      :comm_timeout  => nil,
-      :session_exp   => nil,
-      :retry_total   => nil,
-      :retry_wait    => nil,
-      :cert          => nil,
-      :verbose       => false
+      :uuid         => client.payload_uuid,
+      :transport    => nil,
+      :lhost        => nil,
+      :lport        => nil,
+      :ua           => nil,
+      :proxy_host   => nil,
+      :proxy_port   => nil,
+      :proxy_type   => nil,
+      :proxy_user   => nil,
+      :proxy_pass   => nil,
+      :comm_timeout => nil,
+      :session_exp  => nil,
+      :retry_total  => nil,
+      :retry_wait   => nil,
+      :cert         => nil,
+      :verbose      => false
     }
 
     valid = true
@@ -681,31 +686,29 @@ class Console::CommandDispatcher::Core
       case opt
       when '-c'
         opts[:cert] = val
-      when '-u'
-        opts[:uri] = val
       when '-i'
         transport_index = val.to_i
-      when '-lu'
+      when '-u'
         opts[:luri] = val
-      when '-ph'
+      when '-H'
         opts[:proxy_host] = val
-      when '-pp'
+      when '-P'
         opts[:proxy_port] = val.to_i
-      when '-pt'
+      when '-B'
         opts[:proxy_type] = val
-      when '-pu'
+      when '-U'
         opts[:proxy_user] = val
-      when '-ps'
+      when '-N'
         opts[:proxy_pass] = val
-      when '-ua'
+      when '-A'
         opts[:ua] = val
-      when '-to'
+      when '-C'
         opts[:comm_timeout] = val.to_i if val
-      when '-ex'
+      when '-X'
         opts[:session_exp] = val.to_i if val
-      when '-rt'
+      when '-T'
         opts[:retry_total] = val.to_i if val
-      when '-rw'
+      when '-W'
         opts[:retry_wait] = val.to_i if val
       when '-p'
         opts[:lport] = val.to_i if val
@@ -742,14 +745,7 @@ class Console::CommandDispatcher::Core
       # this will output the session timeout first
       print_timeouts(result)
 
-      columns =[
-        'ID',
-        'Curr',
-        'URL',
-        'Comms T/O',
-        'Retry Total',
-        'Retry Wait'
-      ]
+      columns = ['ID', 'Curr', 'URL', 'Comms T/O', 'Retry Total', 'Retry Wait']
 
       if opts[:verbose]
         columns << 'User Agent'
@@ -766,8 +762,8 @@ class Console::CommandDispatcher::Core
         'Columns'   => columns)
 
       sorted_by_url.each_with_index do |t, i|
-        entry = [ i+1, (current_transport_url == t[:url]) ? '*' : '', t[:url],
-                  t[:comm_timeout], t[:retry_total], t[:retry_wait] ]
+        entry = [i + 1, current_transport_url == t[:url] ? '*' : '', t[:url],
+                  t[:comm_timeout], t[:retry_total], t[:retry_wait]]
 
         if opts[:verbose]
           entry << t[:ua]
@@ -782,42 +778,42 @@ class Console::CommandDispatcher::Core
 
       print("\n" + tbl.to_s + "\n")
     when 'next'
-      print_status("Changing to next transport ...")
+      print_status('Changing to next transport ...')
       if client.core.transport_next
-        print_good("Successfully changed to the next transport, killing current session.")
+        print_good('Successfully changed to the next transport, killing current session.')
         client.shutdown_passive_dispatcher
         shell.stop
       else
-        print_error("Failed to change transport, please check the parameters")
+        print_error('Failed to change transport, please check the parameters')
       end
     when 'prev'
-      print_status("Changing to previous transport ...")
+      print_status('Changing to previous transport ...')
       if client.core.transport_prev
-        print_good("Successfully changed to the previous transport, killing current session.")
+        print_good('Successfully changed to the previous transport, killing current session.')
         client.shutdown_passive_dispatcher
         shell.stop
       else
-        print_error("Failed to change transport, please check the parameters")
+        print_error('Failed to change transport, please check the parameters')
       end
     when 'change'
-      print_status("Changing to new transport ...")
+      print_status('Changing to new transport ...')
       if client.core.transport_change(opts)
         print_good("Successfully added #{opts[:transport]} transport, killing current session.")
         client.shutdown_passive_dispatcher
         shell.stop
       else
-        print_error("Failed to change transport, please check the parameters")
+        print_error('Failed to change transport, please check the parameters')
       end
     when 'add'
-      print_status("Adding new transport ...")
+      print_status('Adding new transport ...')
       if client.core.transport_add(opts)
         print_good("Successfully added #{opts[:transport]} transport.")
       else
-        print_error("Failed to add transport, please check the parameters")
+        print_error('Failed to add transport, please check the parameters')
       end
     when 'remove'
       if opts[:transport] && !opts[:transport].end_with?('_tcp') && opts[:uri].nil?
-        print_error("HTTP/S transport specified without session URI")
+        print_error('HTTP/S transport specified without session URI')
         return
       end
 
@@ -829,7 +825,7 @@ class Console::CommandDispatcher::Core
           opts[:transport] = "reverse_#{uri.scheme}"
           opts[:lhost]     = uri.host
           opts[:lport]     = uri.port
-          opts[:uri]       = uri.path[1..-2] if uri.scheme.include?("http")
+          opts[:uri]       = uri.path[1..-2] if uri.scheme.include?('http')
 
         rescue URI::InvalidURIError
           print_error("Failed to parse URL: #{url_to_delete}")
@@ -837,11 +833,11 @@ class Console::CommandDispatcher::Core
         end
       end
 
-      print_status("Removing transport ...")
+      print_status('Removing transport ...')
       if client.core.transport_remove(opts)
         print_good("Successfully removed #{opts[:transport]} transport.")
       else
-        print_error("Failed to remove transport, please check the parameters")
+        print_error('Failed to remove transport, please check the parameters')
       end
     end
   end
@@ -849,8 +845,8 @@ class Console::CommandDispatcher::Core
   @@migrate_opts = Rex::Parser::Arguments.new(
     '-P' => [true, 'PID to migrate to.'],
     '-N' => [true, 'Process name to migrate to.'],
-    '-p' => [true,  'Writable path - Linux only (eg. /tmp).'],
-    '-t' => [true,  'The number of seconds to wait for migration to finish (default: 60).'],
+    '-p' => [true, 'Writable path - Linux only (eg. /tmp).'],
+    '-t' => [true, 'The number of seconds to wait for migration to finish (default: 60).'],
     '-h' => [false, 'Help menu.']
   )
 
@@ -898,7 +894,7 @@ class Console::CommandDispatcher::Core
         pid = val.to_i
       when '-N'
         if val.to_s.empty?
-          print_error("No process name provided")
+          print_error('No process name provided')
           return
         end
         # this will migrate to the first process with a matching name
@@ -980,23 +976,23 @@ class Console::CommandDispatcher::Core
   end
 
   def cmd_load_help
-    print_line("Usage: load ext1 ext2 ext3 ...")
+    print_line('Usage: load ext1 ext2 ext3 ...')
     print_line
-    print_line "Loads a meterpreter extension module or modules."
-    print_line @@load_opts.usage
+    print_line('Loads a meterpreter extension module or modules.')
+    print_line(@@load_opts.usage)
   end
 
   #
   # Loads one or more meterpreter extensions.
   #
   def cmd_load(*args)
-    if (args.length == 0)
-      args.unshift("-h")
+    if args.length == 0
+      args.unshift('-h')
     end
 
     @@load_opts.parse(args) { |opt, idx, val|
       case opt
-      when "-l"
+      when '-l'
         exts = SortedSet.new
         msf_path = MetasploitPayloads.msf_meterpreter_dir
         gem_path = MetasploitPayloads.local_meterpreter_dir
@@ -1010,7 +1006,7 @@ class Console::CommandDispatcher::Core
         print(exts.to_a.join("\n") + "\n")
 
         return true
-      when "-h"
+      when '-h'
         cmd_load_help
         return true
       end
@@ -1038,7 +1034,7 @@ class Console::CommandDispatcher::Core
         next
       end
 
-      print_line("success.")
+      print_line('Success.')
     }
 
     return true
@@ -1068,9 +1064,9 @@ class Console::CommandDispatcher::Core
   alias cmd_use_tabs cmd_load_tabs
 
   def cmd_read_help
-    print_line "Usage: read <channel_id> [length]"
+    print_line('Usage: read <channel_id> [length]')
     print_line
-    print_line "Reads data from the supplied channel."
+    print_line('Reads data from the supplied channel.')
     print_line
   end
 
@@ -1078,7 +1074,7 @@ class Console::CommandDispatcher::Core
   # Reads data from a channel.
   #
   def cmd_read(*args)
-    if (args.length == 0)
+    if args.length == 0
       cmd_read_help
       return true
     end
@@ -1087,17 +1083,17 @@ class Console::CommandDispatcher::Core
     length  = (args.length >= 2) ? args[1].to_i : 16384
     channel = client.find_channel(cid)
 
-    if (!channel)
+    unless channel
       print_error("Channel #{cid} is not valid.")
       return true
     end
 
     data = channel.read(length)
 
-    if (data and data.length)
+    if data && data.length
       print("Read #{data.length} bytes from #{cid}:\n\n#{data}\n")
     else
-      print_error("No data was returned.")
+      print_error('No data was returned.')
     end
 
     return true
@@ -1106,11 +1102,11 @@ class Console::CommandDispatcher::Core
   alias cmd_read_tabs cmd_close_tabs
 
   def cmd_run_help
-    print_line "Usage: run <script> [arguments]"
+    print_line('Usage: run <script> [arguments]')
     print_line
-    print_line "Executes a ruby script or Metasploit Post module in the context of the"
-    print_line "meterpreter session.  Post modules can take arguments in var=val format."
-    print_line "Example: run post/foo/bar BAZ=abcd"
+    print_line('Executes a ruby script or Metasploit Post module in the context of the')
+    print_line('meterpreter session.  Post modules can take arguments in var=val format.')
+    print_line('Example: run post/foo/bar BAZ=abcd')
     print_line
   end
 
@@ -1129,7 +1125,7 @@ class Console::CommandDispatcher::Core
       # First try it as a Post module if we have access to the Metasploit
       # Framework instance.  If we don't, or if no such module exists,
       # fall back to using the scripting interface.
-      if (msf_loaded? and mod = client.framework.modules.create(script_name))
+      if msf_loaded? && mod = client.framework.modules.create(script_name)
         original_mod = mod
         reloaded_mod = client.framework.modules.reload_module(original_mod)
 
@@ -1160,11 +1156,12 @@ class Console::CommandDispatcher::Core
 
   def cmd_run_tabs(str, words)
     tabs = []
-    if(not words[1] or not words[1].match(/^\//))
+    unless words[1] && words[1].match(/^\//)
       begin
-        if (msf_loaded?)
+        if msf_loaded?
           tabs += tab_complete_postmods
         end
+
         [
           ::Msf::Sessions::Meterpreter.script_base,
           ::Msf::Sessions::Meterpreter.user_script_base
@@ -1178,7 +1175,8 @@ class Console::CommandDispatcher::Core
       rescue Exception
       end
     end
-    return tabs.map { |e| e.sub(/\.rb$/, '') }
+
+    tabs.map { |e| e.sub(/\.rb$/, '') }
   end
 
 
@@ -1187,9 +1185,10 @@ class Console::CommandDispatcher::Core
   #
   def cmd_bgrun(*args)
     if args.length == 0
-      print_line(
-        "Usage: bgrun <script> [arguments]\n\n" +
-        "Executes a ruby script in the context of the meterpreter session.")
+        print_line('Usage: bgrun <script> [arguments]')
+        print_line
+        print_line('Executes a ruby script in the context of the meterpreter session.')
+        print_line
       return true
     end
 
@@ -1226,7 +1225,7 @@ class Console::CommandDispatcher::Core
   #
   def cmd_bgkill(*args)
     if args.length == 0
-      print_line("Usage: bgkill [id]")
+      print_line('Usage: bgkill [id]')
       return
     end
 
@@ -1254,9 +1253,9 @@ class Console::CommandDispatcher::Core
   end
 
   def cmd_info_help
-    print_line 'Usage: info <module>'
+    print_line('Usage: info <module>')
     print_line
-    print_line 'Prints information about a post-exploitation module'
+    print_line('Prints information about a post-exploitation module')
     print_line
   end
 
@@ -1268,7 +1267,7 @@ class Console::CommandDispatcher::Core
   def cmd_info(*args)
     return unless msf_loaded?
 
-    if args.length != 1 or args.include?("-h")
+    if args.length != 1 or args.include?('-h')
       cmd_info_help
       return
     end
@@ -1277,7 +1276,7 @@ class Console::CommandDispatcher::Core
     mod = client.framework.modules.create(module_name);
 
     if mod.nil?
-      print_error 'Invalid module: ' << module_name
+      print_error("Invalid module: #{module_name}")
     end
 
     if (mod)
@@ -1296,18 +1295,18 @@ class Console::CommandDispatcher::Core
   # Writes data to a channel.
   #
   @@write_opts = Rex::Parser::Arguments.new(
-    "-f" => [ true,  "Write the contents of a file on disk" ],
-    "-h" => [ false, "Help menu."                           ])
+    '-f' => [true, 'Write the contents of a file on disk'],
+    '-h' => [false, 'Help menu.'])
 
   def cmd_write_help
-    print_line "Usage: write [options] channel_id"
+    print_line('Usage: write [options] channel_id')
     print_line
-    print_line "Writes data to the supplied channel."
-    print_line @@write_opts.usage
+    print_line('Writes data to the supplied channel.')
+    print_line(@@write_opts.usage)
   end
 
   def cmd_write(*args)
-    if (args.length == 0 or args.include?("-h"))
+    if args.length == 0 || args.include?("-h")
       cmd_write_help
       return
     end
@@ -1325,14 +1324,14 @@ class Console::CommandDispatcher::Core
     }
 
     # Find the channel associated with this cid, assuming the cid is valid.
-    if ((!cid) or (!(channel = client.find_channel(cid))))
-      print_error("Invalid channel identifier specified.")
+    unless cid && channel = client.find_channel(cid)
+      print_error('Invalid channel identifier specified.')
       return true
     end
 
     # If they supplied a source file, read in its contents and write it to
     # the channel
-    if (src_file)
+    if src_file
       begin
         data = ''
 
@@ -1345,7 +1344,7 @@ class Console::CommandDispatcher::Core
         return true
       end
 
-      if (data and data.length > 0)
+      if data && data.length > 0
         channel.write(data)
         print_status("Wrote #{data.length} bytes to channel #{cid}.")
       else
@@ -1354,18 +1353,20 @@ class Console::CommandDispatcher::Core
       end
     # Otherwise, read from the input descriptor until we're good to go.
     else
-      print("Enter data followed by a '.' on an empty line:\n\n")
+      print_line('Enter data followed by a "." on an empty line:')
+      print_line
+      print_line
 
       data = ''
 
       # Keep truckin'
-      while (s = shell.input.gets)
-        break if (s =~ /^\.\r?\n?$/)
+      while s = shell.input.gets
+        break if s =~ /^\.\r?\n?$/
         data += s
       end
 
-      if (!data or data.length == 0)
-        print_error("No data to send.")
+      if !data || data.length == 0
+        print_error('No data to send.')
       else
         channel.write(data)
         print_status("Wrote #{data.length} bytes to channel #{cid}.")
@@ -1376,9 +1377,9 @@ class Console::CommandDispatcher::Core
   end
 
   def cmd_resource_help
-    print_line "Usage: resource <path1> [path2 ...]"
+    print_line('Usage: resource <path1> [path2 ...]')
     print_line
-    print_line "Run the commands stored in the supplied files."
+    print_line('Run the commands stored in the supplied files.')
     print_line
   end
 
@@ -1386,6 +1387,7 @@ class Console::CommandDispatcher::Core
     if args.empty?
       return false
     end
+
     args.each do |glob|
       files = ::Dir.glob(::File.expand_path(glob))
       if files.empty?
@@ -1398,9 +1400,9 @@ class Console::CommandDispatcher::Core
           print_error("Could not read file #{filename}")
           next
         else
-          ::File.open(filename, "r").each_line do |line|
+          ::File.open(filename, 'r').each_line do |line|
             next if line.strip.length < 1
-            next if line[0,1] == "#"
+            next if line[0,1] == '#'
             begin
               print_status("Running #{line}")
               client.console.run_single(line)
@@ -1422,19 +1424,20 @@ class Console::CommandDispatcher::Core
 
   def cmd_enable_unicode_encoding
     client.encode_unicode = true
-    print_status("Unicode encoding is enabled")
+    print_status('Unicode encoding is enabled')
   end
 
   def cmd_disable_unicode_encoding
     client.encode_unicode = false
-    print_status("Unicode encoding is disabled")
+    print_status('Unicode encoding is disabled')
   end
 
-  @@client_extension_search_paths = [ ::File.join(Rex::Root, "post", "meterpreter", "ui", "console", "command_dispatcher") ]
+  @@client_extension_search_paths = [::File.join(Rex::Root, 'post', 'meterpreter', 'ui', 'console', 'command_dispatcher')]
 
   def self.add_client_extension_search_path(path)
     @@client_extension_search_paths << path unless @@client_extension_search_paths.include?(path)
   end
+
   def self.client_extension_search_paths
     @@client_extension_search_paths
   end
@@ -1474,12 +1477,14 @@ protected
           print_error("Failed to load client script file: #{path}")
           return false
         end
+
       else
         # the klass is already loaded, from a previous invocation
         loaded = true
         break
       end
     end
+
     unless loaded
       print_error("Failed to load client portion of #{mod}.")
       return false
