@@ -1,10 +1,8 @@
 ##
-# This module requires Metasploit: http://metasploit.com/download
+# This module requires Metasploit: https://metasploit.com/download
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-require 'msf/core'
-
 class MetasploitModule < Msf::Exploit::Remote
   Rank = NormalRanking
 
@@ -52,6 +50,7 @@ class MetasploitModule < Msf::Exploit::Remote
         ],
       'References'     =>
         [
+          [ 'AKA', 'stagefright' ],
           [ 'CVE', '2015-3864' ],
           [ 'URL', 'https://blog.exodusintel.com/2015/08/13/stagefright-mission-accomplished/' ],
           [ 'URL', 'http://googleprojectzero.blogspot.com/2015/09/stagefrightened.html' ],
@@ -67,7 +66,7 @@ class MetasploitModule < Msf::Exploit::Remote
           'Space'    => 2048,
           'DisableNops' => true,
         },
-      #'DefaultOptions' => { 'PAYLOAD' => 'linux/armle/mettle/reverse_tcp' },
+      #'DefaultOptions' => { 'PAYLOAD' => 'linux/armle/meterpreter/reverse_tcp' },
       'Platform'       => 'linux',
       'Arch'           => [ARCH_ARMLE], # TODO: , ARCH_X86, ARCH_X64, ARCH_MIPSLE],
       'Targets'        =>
@@ -354,7 +353,7 @@ class MetasploitModule < Msf::Exploit::Remote
     register_options(
       [
         OptBool.new('OBFUSCATE', [false, 'Enable JavaScript obfuscation', false])
-      ], self.class)
+      ])
 =end
   end
 
@@ -1208,5 +1207,4 @@ Please wait while we locate your content...
 
     details[my_target['Rop']]
   end
-
 end
